@@ -688,6 +688,7 @@ LoggingConfigurationTypeDef = TypedDict(
     "LoggingConfigurationTypeDef",
     {
         "EnableSIPLogs": bool,
+        "EnableMediaMetricLogs": bool,
     },
     total=False,
 )
@@ -1457,7 +1458,9 @@ UpdateGlobalSettingsRequestRequestTypeDef = TypedDict(
 GetSipMediaApplicationAlexaSkillConfigurationResponseTypeDef = TypedDict(
     "GetSipMediaApplicationAlexaSkillConfigurationResponseTypeDef",
     {
-        "SipMediaApplicationAlexaSkillConfiguration": SipMediaApplicationAlexaSkillConfigurationTypeDef,
+        "SipMediaApplicationAlexaSkillConfiguration": (
+            SipMediaApplicationAlexaSkillConfigurationTypeDef
+        ),
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
@@ -1471,7 +1474,9 @@ _RequiredPutSipMediaApplicationAlexaSkillConfigurationRequestRequestTypeDef = Ty
 _OptionalPutSipMediaApplicationAlexaSkillConfigurationRequestRequestTypeDef = TypedDict(
     "_OptionalPutSipMediaApplicationAlexaSkillConfigurationRequestRequestTypeDef",
     {
-        "SipMediaApplicationAlexaSkillConfiguration": SipMediaApplicationAlexaSkillConfigurationTypeDef,
+        "SipMediaApplicationAlexaSkillConfiguration": (
+            SipMediaApplicationAlexaSkillConfigurationTypeDef
+        ),
     },
     total=False,
 )
@@ -1487,7 +1492,9 @@ class PutSipMediaApplicationAlexaSkillConfigurationRequestRequestTypeDef(
 PutSipMediaApplicationAlexaSkillConfigurationResponseTypeDef = TypedDict(
     "PutSipMediaApplicationAlexaSkillConfigurationResponseTypeDef",
     {
-        "SipMediaApplicationAlexaSkillConfiguration": SipMediaApplicationAlexaSkillConfigurationTypeDef,
+        "SipMediaApplicationAlexaSkillConfiguration": (
+            SipMediaApplicationAlexaSkillConfigurationTypeDef
+        ),
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
